@@ -3,6 +3,14 @@ import json
 from datetime import date, datetime
 from typing import List, AnyStr, Any, Type, Dict
 
+try:
+    # https://github.com/OpenAPITools/openapi-generator/issues/7010
+    from typing import GenericMeta  # python < 3.7
+except ImportError:
+    # in 3.7, genericmeta doesn't exist but we don't need it
+    class GenericMeta(type):
+        pass
+
 
 class SwaggerValidator(object):
     """
@@ -163,9 +171,3 @@ def json_dumps_unicode(obj):
 
 class InvalidSwaggerDataType(Exception):
     pass
-
-try:
-    from typing import GenericMeta  # python < 3.7
-except ImportError:
-    # in 3.7, genericmeta doesn't exist but we don't need it
-    class GenericMeta(type): pass
